@@ -65,6 +65,7 @@ class Invoice(Model):
     def __init__(self, invoice):
         pool = Pool()
         Invoice = pool.get('account.invoice')
+        super().__init__()
         if int(invoice) >= 0:
             invoice = Invoice(int(invoice))
             with Transaction().set_context(language=invoice.party_lang):
@@ -156,12 +157,12 @@ class Invoice(Model):
     @has_goods_assets
     def ship_to_trade_party(self):
         if self.invoice.type == 'out':
-            if getattr(self.invoice, 'sales'):
+            if getattr(self.invoice, 'sales', None):
                 sale = self.invoice.sales[0]  # XXX
                 if sale.shipment_party != self.buyer_trade_party:
                     return sale.shipment_party
         else:
-            if self.invoice.purchases:
+            if getattr(self.invoice, 'purchases', None):
                 purchase = self.invoice.purchases[0]  # XXX
                 address = purchase.warehouse.address
                 if (address and address.party != self.buyer_trade_party):
@@ -171,12 +172,12 @@ class Invoice(Model):
     @has_goods_assets
     def ship_to_trade_address(self):
         if self.invoice.type == 'out':
-            if getattr(self.invoice, 'sales'):
+            if getattr(self.invoice, 'sales', None):
                 sale = self.invoice.sales[0]  # XXX
                 if sale.shipment_party != self.buyer_trade_party:
                     return sale.shipment_address
         else:
-            if getattr(self.invoice, 'purchases'):
+            if getattr(self.invoice, 'purchases', None):
                 purchase = self.invoice.purchases[0]  # XXX
                 address = purchase.warehouse.address
                 if (address and address.party != self.buyer_trade_party):
@@ -186,7 +187,7 @@ class Invoice(Model):
     @has_goods_assets
     def ship_from_trade_party(self):
         if self.invoice.type == 'out':
-            if getattr(self.invoice, 'sales'):
+            if getattr(self.invoice, 'sales', None):
                 sale = self.invoice.sales[0]  # XXX
                 address = sale.warehouse.address
                 if address and address.party != self.seller_trade_party:
@@ -196,7 +197,7 @@ class Invoice(Model):
     @has_goods_assets
     def ship_from_trade_address(self):
         if self.invoice.type == 'out':
-            if getattr(self.invoice, 'sales'):
+            if getattr(self.invoice, 'sales', None):
                 sale = self.invoice.sales[0]  # XXX
                 address = sale.warehouse.address
                 if address and address.party != self.seller_trade_party:
